@@ -1,10 +1,10 @@
-VERSION="1.21"
+VERSION="1.23"
 PACKAGE="blueman"
 WEBSITE="http://blueman-project.org"
-PREFIX="/usr"
-BIN_DIR="/usr/bin"
-ICON_PATH = "/usr/share/blueman/icons"
-UI_PATH = "/usr/share/blueman/ui"
+PREFIX="/usr/local"
+BIN_DIR="/usr/local/bin"
+ICON_PATH = "/usr/local/share/blueman/icons"
+UI_PATH = "/usr/local/share/blueman/ui"
 OBEX_BROWSE_AVAILABLE = True
 DHCP_CONFIG_FILE = "/etc/dhcp3/dhcpd.conf"
 POLKIT = "yes" == "yes"
@@ -16,7 +16,7 @@ import os
 import gettext
 import __builtin__
 
-translation = gettext.translation("blueman", "/usr/share/locale", fallback=True)
+translation = gettext.translation("blueman", "/usr/local/share/locale", fallback=True)
 translation.install(unicode=True)
 __builtin__.ngettext = translation.ungettext
 
