@@ -49,7 +49,7 @@ class DBusService(AppletPlugin):
 		AppletPlugin.add_method(self.on_device_disconnect)
 		
 		self.add_dbus_method(self.ServiceProxy, in_signature="sosas", async_callbacks=("ok","err"))
-		self.add_dbus_method(self.CreateDevice, in_signature="ssbu", async_callbacks=("ok","err"))
+		self.add_dbus_method(self.CreateDevice, in_signature="ssbu", async_callbacks=("_ok","err"))
 		self.add_dbus_method(self.CancelDeviceCreation, in_signature="ss", async_callbacks=("ok","err"))
 		self.add_dbus_method(self.RfcommConnect, in_signature="ss", out_signature="s", async_callbacks=("ok","err"))
 		self.add_dbus_method(self.RfcommDisconnect, in_signature="ss", out_signature="")
@@ -60,16 +60,14 @@ class DBusService(AppletPlugin):
 		self.add_dbus_method(self.SetPluginConfig, in_signature="sb", out_signature="")
 		self.add_dbus_method(self.DisconnectDevice, in_signature="o", out_signature="", async_callbacks=("ok","err"))
 		
-		dbus.SystemBus().add_signal_receiver(self.on_device_added, "DeviceCreated", "org.bluez.Adapter")
-		
-	def on_device_added(self, path):
-		self.RefreshServices(path, (lambda *args: None), (lambda *args: None))
-		
 	def RefreshServices(self, path, ok, err):
 		device = Device(path)
 		def reply(svcs):
-			records = parse_sdp_xml(svcs)
-			sdp_save(device.Address, records)
+			try:
+				records = parse_sdp_xml(svcs)
+				sdp_save(device.Address, records)
+			except:
+				pass
 			ok()
 
 		device.GetInterface().DiscoverServices("", reply_handler=reply, error_handler=err)
@@ -95,12 +93,16 @@ class DBusService(AppletPlugin):
 		
 	def SetPluginConfig(self, plugin, value):
 		self.Applet.Plugins.SetConfig(plugin, value)
-	
-	def ServiceProxy(self, interface, object_path, _method, args, ok, err):
+		
+	def ConnectHelper(self, interface, object_path, _method, args, ok, err):
 		bus = dbus.SystemBus()
 		service = bus.get_object("org.bluez", object_path)
 		method = service.get_dbus_method(_method, interface)
 		
+		method(reply_handler=ok, error_handler=err, *args)
+				
+	
+	def ServiceProxy(self, interface, object_path, _method, args, ok, err):
 		
 		if _method == "Connect":
 			dev = Device(object_path)
@@ -119,14 +121,18 @@ class DBusService(AppletPlugin):
 		self.Applet.Plugins.RunEx("service_connect_handler", cb, interface, object_path, _method, args, ok, err)
 
 		if not self.handled:
-			method(reply_handler=ok, error_handler=err, *args)
+			self.ConnectHelper(interface, object_path, _method, args, ok, err)
 			
 		del self.handled
 		
 	def service_connect_handler(self, interface, object_path, _method, args, ok, err):
 		pass
 
-	def CreateDevice(self, adapter_path, address, pair, time, ok, err):
+	def CreateDevice(self, adapter_path, address, pair, time, _ok, err):
+		def ok(device):
+			_ok(device)
+			self.RefreshServices(device, (lambda *args: None), (lambda *args: None))
+		
 		if self.Applet.Manager:
 			adapter = Adapter(adapter_path)
 				
@@ -142,7 +148,7 @@ class DBusService(AppletPlugin):
 			err()
 	
 	def CancelDeviceCreation(self, adapter_path, address, ok, err):
-		if self.applet.Manager:
+		if self.Applet.Manager:
 			adapter = Adapter(adapter_path)
 
 			adapter.GetInterface().CancelDeviceCreation(address, error_handler=err, reply_handler=ok)
